
#include <windows.h>  
#include "remove.h"  
#include "commctrl.h"


#if defined (WIN32)
	#define IS_WIN32 TRUE
#else
	#define IS_WIN32 FALSE
#endif

#define IS_NT      IS_WIN32 && (BOOL)(GetVersion() < 0x80000000)
#define IS_WIN32S  IS_WIN32 && (BOOL)(!(IS_NT) && (LOBYTE(LOWORD(GetVersion()))<4))
#define IS_WIN95   (BOOL)(!(IS_NT) && !(IS_WIN32S)) && IS_WIN32

HINSTANCE hInst;   // current instance

LPCTSTR lpszAppName = "MyApp";
LPCTSTR lpszTitle   = "ImageList_Remove()"; 


BOOL RegisterWin95( CONST WNDCLASS* lpwc );


int APIENTRY WinMain( HINSTANCE hInstance, HINSTANCE hPrevInstance,
                      LPTSTR lpCmdLine, int nCmdShow)
{
   MSG      msg;
   HWND     hWnd; 
   WNDCLASS wc;

   wc.style         = CS_HREDRAW | CS_VREDRAW;
   wc.lpfnWndProc   = (WNDPROC)WndProc;       
   wc.cbClsExtra    = 0;                      
   wc.cbWndExtra    = 0;                      
   wc.hInstance     = hInstance;              
   wc.hIcon         = LoadIcon (hInstance, lpszAppName); 
   wc.hCursor       = LoadCursor(NULL, IDC_ARROW);
   wc.hbrBackground = (HBRUSH)(COLOR_WINDOW+1);
   wc.lpszMenuName  = lpszAppName;              
   wc.lpszClassName = lpszAppName;              

   if ( IS_WIN95 )
   {
      if ( !RegisterWin95( &wc ) )
         return( FALSE );
   }
   else if ( !RegisterClass( &wc ) )
      return( FALSE );

   hInst = hInstance; 

   hWnd = CreateWindow( lpszAppName, 
                        lpszTitle,    
                        WS_OVERLAPPEDWINDOW, 
                        CW_USEDEFAULT, 0, 
                        CW_USEDEFAULT, 0,  
                        NULL,              
                        NULL,              
                        hInstance,         
                        NULL               
                      );

   if ( !hWnd ) 
      return( FALSE );

   ShowWindow( hWnd, nCmdShow ); 
   UpdateWindow( hWnd );         

   while( GetMessage( &msg, NULL, 0, 0) )   
   {
      TranslateMessage( &msg ); 
      DispatchMessage( &msg );  
   }

   return( msg.wParam ); 
}


BOOL RegisterWin95( CONST WNDCLASS* lpwc )
{
   WNDCLASSEX wcex;

   wcex.style         = lpwc->style;
   wcex.lpfnWndProc   = lpwc->lpfnWndProc;
   wcex.cbClsExtra    = lpwc->cbClsExtra;
   wcex.cbWndExtra    = lpwc->cbWndExtra;
   wcex.hInstance     = lpwc->hInstance;
   wcex.hIcon         = lpwc->hIcon;
   wcex.hCursor       = lpwc->hCursor;
   wcex.hbrBackground = lpwc->hbrBackground;
   wcex.lpszMenuName  = lpwc->lpszMenuName;
   wcex.lpszClassName = lpwc->lpszClassName;

   // Added elements for Windows 95.
   //...............................
   wcex.cbSize = sizeof(WNDCLASSEX);
   wcex.hIconSm = LoadImage(wcex.hInstance, lpwc->lpszClassName, 
                            IMAGE_ICON, 16, 16,
                            LR_DEFAULTCOLOR );
			
   return RegisterClassEx( &wcex );
}


LRESULT CALLBACK WndProc( HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM lParam )
{
static HIMAGELIST hList  = NULL;
static int        nSize  = 32;

   switch( uMsg )
   {
      case WM_CREATE :
              InitCommonControls();

              // Create the image list.
              //.......................
              hList = ImageList_Create( nSize, nSize, ILC_COLOR | ILC_MASK, 1, 1 );
              break;

      case WM_PAINT :
              {
                 PAINTSTRUCT ps;
                 int         i, nItems;

                 // Retrieve the number of images.
                 //...............................
                 nItems = ImageList_GetImageCount( hList );

                 // Paint the images on the client area.
                 //.....................................
                 BeginPaint( hWnd, &ps );
                 for ( i=0; i<nItems; i++ )
                    ImageList_Draw( hList, i, ps.hdc, (i*nSize)+10, 10,
                                 (i == nItems - 1) ? 
                                 ILD_SELECTED : ILD_NORMAL);
                 EndPaint( hWnd, &ps );
              }
              break;

      case WM_COMMAND :
              switch( LOWORD( wParam ) )
              {
                 case IDM_ARROW :
                 case IDM_WAITING :
                 case IDM_WORKING :
                        ImageList_AddIcon( hList, LoadCursor( NULL, 
                                                    LOWORD( wParam ) == IDM_ARROW ? IDC_ARROW :
                                                    LOWORD( wParam ) == IDM_WAITING ? IDC_WAIT :
                                                    IDC_APPSTARTING ) );
                        InvalidateRect( hWnd, NULL, TRUE );
                        break;

                 case IDM_REPARROW :
                 case IDM_REPWAITING :
                 case IDM_REPWORKING :
                        ImageList_ReplaceIcon( hList, ImageList_GetImageCount( hList )-1,
                                               LoadCursor( NULL, 
                                                LOWORD( wParam ) == IDM_REPARROW ? IDC_ARROW :
                                                LOWORD( wParam ) == IDM_REPWAITING ? IDC_WAIT : 
                                                IDC_APPSTARTING ) );
                        InvalidateRect( hWnd, NULL, TRUE );
                        break;

                 case IDM_REMITEM :
                        ImageList_Remove( hList, ImageList_GetImageCount( hList ) - 1 );
                        InvalidateRect( hWnd, NULL, TRUE );
                        break;

                 case IDM_REMALL :
                        ImageList_RemoveAll( hList );
                        InvalidateRect( hWnd, NULL, TRUE );
                        break;

                 case IDM_ENLARGE :
                        nSize += 5;
                        ImageList_SetIconSize( hList, nSize, nSize );
                        InvalidateRect( hWnd, NULL, TRUE );
                        break;

                 case IDM_REDUCE :
                        nSize -= 5;
                        ImageList_SetIconSize( hList, nSize, nSize );
                        InvalidateRect( hWnd, NULL, TRUE );
                        break;

                 case IDM_ABOUT :
                        DialogBox( hInst, "AboutBox", hWnd, (DLGPROC)About );
                        break;

                 case IDM_EXIT :
                        DestroyWindow( hWnd );
                        break;
              }
              break;
      
      case WM_DESTROY :
              if ( hList )
                 ImageList_Destroy( hList );

              PostQuitMessage(0);
              break;

      default :
            return( DefWindowProc( hWnd, uMsg, wParam, lParam ) );
   }

   return( 0L );
}




LRESULT CALLBACK About( HWND hDlg,           
                        UINT message,        
                        WPARAM wParam,       
                        LPARAM lParam)
{
   switch (message) 
   {
       case WM_INITDIALOG: 
               return (TRUE);

       case WM_COMMAND:                              
               if (   LOWORD(wParam) == IDOK         
                   || LOWORD(wParam) == IDCANCEL)    
               {
                       EndDialog(hDlg, TRUE);        
                       return (TRUE);
               }
               break;
   }

   return (FALSE); 
}
